//// [tests/cases/compiler/requireOfAnEmptyFile1.ts] ////

//// [requireOfAnEmptyFile1_a.ts]
//requireOfAnEmptyFile1

import fs = require('./requireOfAnEmptyFile1_b');

//// [requireOfAnEmptyFile1_b.ts]


//// [requireOfAnEmptyFile1_b.js]
//// [requireOfAnEmptyFile1_a.js]
//requireOfAnEmptyFile1
